.. image:: assets/logo_200w.png

|GHA tests| |Codecov report| |readthedocs|

.. inclusion-marker-do-not-remove

autoregistry
==============

autoregistry is a


Features
========

Installation
============

.. code-block:: bash

   python -m pip install git+https://github.com/BrianPugh/autoregistry.git


Usage
=====

.. code-block:: python

   import autoregistry




.. |GHA tests| image:: https://github.com/BrianPugh/autoregistry/workflows/tests/badge.svg
   :target: https://github.com/BrianPugh/autoregistry/actions?query=workflow%3Atests
   :alt: GHA Status
.. |Codecov report| image:: https://codecov.io/github/BrianPugh/autoregistry/coverage.svg?branch=main
   :target: https://codecov.io/github/BrianPugh/autoregistry?branch=main
   :alt: Coverage
.. |readthedocs| image:: https://readthedocs.org/projects/autoregistry/badge/?version=latest
        :target: https://autoregistry.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
